==> estateplat-common-1.2.3-20180523.065010-94-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtZt.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    新建商品房买卖合同主体历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht_zt")
public class FcjyXjspfBaMmhtZt {
    @Id
    private String ztlsid;//主键
    private String htlsid;//合同历史表id
    private String ztid;//新建商品房买卖合同主体表主键
    private String htid;//合同id
    private String ztlb;//主体类别(买卖合同主体类别字典表)
    private String ztxm;//主体姓名
    private String dz;//地址
    private String yb;//邮编
    private String dlrxm;//代理人姓名
    private String dlrzjlb;//代理人证件类别(证件类别字典表)
    private String dlrzjhm;//代理人证件号码
    private String dlrdz;//代理人地址
    private String dlrlxdh;//代理人联系电话
    private String dlryb;//代理人邮编
    private String dlrgj;//代理人国籍
    private Date dlrcsrq;//代理人出生日期
    private String dlrxb;//代理人性别
    private String dlrgjdqlx;//代理人国家/地区类型
    private String dlrgjdq;//代理人国家/地区（国家和地区字典表）
    private String dbrxm;//代表人姓名
    private String dbrzjlb;//代表人证件类别(证件类别字典表)
    private String dbrzjhm;//代表人证件号码
    private String dbrdz;//代表人地址
    private String dbrlxdh;//代表人联系电话
    private String dbryb;//代表人邮编
    private String dbrgj;//代表人国籍
    private Date dbrcsrq;//代表人出生日期
    private String dbrxb;//代表人性别(性别字典表)
    private String dbrgjdqlx;//代表人国家/地区类型
    private String dbrgjdq;//代表人国家/地区（国家和地区字典表）
    private String yyzzzch;//营业执照注册号
    private String qyzzzsh;//企业资质证书号
    private String wtxsjjjg;//委托销售经纪机构
    private String jjjgbazmh;//经纪机构备案证明号
    private String dbrlx;//代表人类型
    private String jjjgtxdz;//经纪机构通讯地址
    private String jjjgyzbm;//经纪机构邮政编码
    private String jjjgyyzzzch;//经纪机构营业执照注册号
    private String dlrlx;//代理人类型
    private Integer sxh;//顺序号
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getZtlsid() {
        return ztlsid;
    }

    public void setZtlsid(String ztlsid) {
        this.ztlsid = ztlsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getZtlb() {
        return ztlb;
    }

    public void setZtlb(String ztlb) {
        this.ztlb = ztlb;
    }

    public String getZtxm() {
        return ztxm;
    }

    public void setZtxm(String ztxm) {
        this.ztxm = ztxm;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }


    public String getDlrxm() {
        return dlrxm;
    }

    public void setDlrxm(String dlrxm) {
        this.dlrxm = dlrxm;
    }

    public String getDlrzjlb() {
        return dlrzjlb;
    }

    public void setDlrzjlb(String dlrzjlb) {
        this.dlrzjlb = dlrzjlb;
    }

    public String getDlrzjhm() {
        return dlrzjhm;
    }

    public void setDlrzjhm(String dlrzjhm) {
        this.dlrzjhm = dlrzjhm;
    }

    public String getDlrdz() {
        return dlrdz;
    }

    public void setDlrdz(String dlrdz) {
        this.dlrdz = dlrdz;
    }

    public String getDlrlxdh() {
        return dlrlxdh;
    }

    public void setDlrlxdh(String dlrlxdh) {
        this.dlrlxdh = dlrlxdh;
    }

    public String getDlryb() {
        return dlryb;
    }

    public void setDlryb(String dlryb) {
        this.dlryb = dlryb;
    }

    public String getDlrgj() {
        return dlrgj;
    }

    public void setDlrgj(String dlrgj) {
        this.dlrgj = dlrgj;
    }

    public Date getDlrcsrq() {
        return dlrcsrq;
    }

    public void setDlrcsrq(Date dlrcsrq) {
        this.dlrcsrq = dlrcsrq;
    }

    public String getDlrxb() {
        return dlrxb;
    }

    public void setDlrxb(String dlrxb) {
        this.dlrxb = dlrxb;
    }

    public String getDbrxm() {
        return dbrxm;
    }

    public void setDbrxm(String dbrxm) {
        this.dbrxm = dbrxm;
    }

    public String getDbrzjlb() {
        return dbrzjlb;
    }

    public void setDbrzjlb(String dbrzjlb) {
        this.dbrzjlb = dbrzjlb;
    }

    public String getDbrzjhm() {
        return dbrzjhm;
    }

    public void setDbrzjhm(String dbrzjhm) {
        this.dbrzjhm = dbrzjhm;
    }

    public String getDbrdz() {
        return dbrdz;
    }

    public void setDbrdz(String dbrdz) {
        this.dbrdz = dbrdz;
    }

    public String getDbrlxdh() {
        return dbrlxdh;
    }

    public void setDbrlxdh(String dbrlxdh) {
        this.dbrlxdh = dbrlxdh;
    }

    public String getDbryb() {
        return dbryb;
    }

    public void setDbryb(String dbryb) {
        this.dbryb = dbryb;
    }

    public String getDbrgj() {
        return dbrgj;
    }

    public void setDbrgj(String dbrgj) {
        this.dbrgj = dbrgj;
    }

    public Date getDbrcsrq() {
        return dbrcsrq;
    }

    public void setDbrcsrq(Date dbrcsrq) {
        this.dbrcsrq = dbrcsrq;
    }

    public String getDbrxb() {
        return dbrxb;
    }

    public void setDbrxb(String dbrxb) {
        this.dbrxb = dbrxb;
    }

    public String getYyzzzch() {
        return yyzzzch;
    }

    public void setYyzzzch(String yyzzzch) {
        this.yyzzzch = yyzzzch;
    }

    public String getQyzzzsh() {
        return qyzzzsh;
    }

    public void setQyzzzsh(String qyzzzsh) {
        this.qyzzzsh = qyzzzsh;
    }

    public String getWtxsjjjg() {
        return wtxsjjjg;
    }

    public void setWtxsjjjg(String wtxsjjjg) {
        this.wtxsjjjg = wtxsjjjg;
    }

    public String getJjjgbazmh() {
        return jjjgbazmh;
    }

    public void setJjjgbazmh(String jjjgbazmh) {
        this.jjjgbazmh = jjjgbazmh;
    }

    public String getDbrlx() {
        return dbrlx;
    }

    public void setDbrlx(String dbrlx) {
        this.dbrlx = dbrlx;
    }

    public String getJjjgtxdz() {
        return jjjgtxdz;
    }

    public void setJjjgtxdz(String jjjgtxdz) {
        this.jjjgtxdz = jjjgtxdz;
    }

    public String getJjjgyzbm() {
        return jjjgyzbm;
    }

    public void setJjjgyzbm(String jjjgyzbm) {
        this.jjjgyzbm = jjjgyzbm;
    }

    public String getJjjgyyzzzch() {
        return jjjgyyzzzch;
    }

    public void setJjjgyyzzzch(String jjjgyyzzzch) {
        this.jjjgyyzzzch = jjjgyyzzzch;
    }

    public String getDlrlx() {
        return dlrlx;
    }

    public void setDlrlx(String dlrlx) {
        this.dlrlx = dlrlx;
    }

    public String getDlrgjdqlx() {
        return dlrgjdqlx;
    }

    public void setDlrgjdqlx(String dlrgjdqlx) {
        this.dlrgjdqlx = dlrgjdqlx;
    }

    public String getDlrgjdq() {
        return dlrgjdq;
    }

    public void setDlrgjdq(String dlrgjdq) {
        this.dlrgjdq = dlrgjdq;
    }

    public String getDbrgjdqlx() {
        return dbrgjdqlx;
    }

    public void setDbrgjdqlx(String dbrgjdqlx) {
        this.dbrgjdqlx = dbrgjdqlx;
    }

    public String getDbrgjdq() {
        return dbrgjdq;
    }

    public void setDbrgjdq(String dbrgjdq) {
        this.dbrgjdq = dbrgjdq;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180612.083341-113-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtZt.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    新建商品房买卖合同主体历史表
 */
@Table(name = "fcjy_xjspf_ba_mmht_zt")
public class FcjyXjspfBaMmhtZt implements Serializable {
    @Id
    private String ztlsid;//主键
    private String htlsid;//合同历史表id
    private String ztid;//新建商品房买卖合同主体表主键
    private String htid;//合同id
    private String ztlb;//主体类别(买卖合同主体类别字典表)
    private String ztxm;//主体姓名
    private String dz;//地址
    private String yb;//邮编
    private String dlrxm;//代理人姓名
    private String dlrzjlb;//代理人证件类别(证件类别字典表)
    private String dlrzjhm;//代理人证件号码
    private String dlrdz;//代理人地址
    private String dlrlxdh;//代理人联系电话
    private String dlryb;//代理人邮编
    private String dlrgj;//代理人国籍
    private Date dlrcsrq;//代理人出生日期
    private String dlrxb;//代理人性别
    private String dlrgjdqlx;//代理人国家/地区类型
    private String dlrgjdq;//代理人国家/地区（国家和地区字典表）
    private String dbrxm;//代表人姓名
    private String dbrzjlb;//代表人证件类别(证件类别字典表)
    private String dbrzjhm;//代表人证件号码
    private String dbrdz;//代表人地址
    private String dbrlxdh;//代表人联系电话
    private String dbryb;//代表人邮编
    private String dbrgj;//代表人国籍
    private Date dbrcsrq;//代表人出生日期
    private String dbrxb;//代表人性别(性别字典表)
    private String dbrgjdqlx;//代表人国家/地区类型
    private String dbrgjdq;//代表人国家/地区（国家和地区字典表）
    private String yyzzzch;//营业执照注册号
    private String qyzzzsh;//企业资质证书号
    private String wtxsjjjg;//委托销售经纪机构
    private String jjjgbazmh;//经纪机构备案证明号
    private String dbrlx;//代表人类型
    private String jjjgtxdz;//经纪机构通讯地址
    private String jjjgyzbm;//经纪机构邮政编码
    private String jjjgyyzzzch;//经纪机构营业执照注册号
    private String dlrlx;//代理人类型
    private Integer sxh;//顺序号
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getZtlsid() {
        return ztlsid;
    }

    public void setZtlsid(String ztlsid) {
        this.ztlsid = ztlsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getZtid() {
        return ztid;
    }

    public void setZtid(String ztid) {
        this.ztid = ztid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getZtlb() {
        return ztlb;
    }

    public void setZtlb(String ztlb) {
        this.ztlb = ztlb;
    }

    public String getZtxm() {
        return ztxm;
    }

    public void setZtxm(String ztxm) {
        this.ztxm = ztxm;
    }

    public String getDz() {
        return dz;
    }

    public void setDz(String dz) {
        this.dz = dz;
    }

    public String getYb() {
        return yb;
    }

    public void setYb(String yb) {
        this.yb = yb;
    }


    public String getDlrxm() {
        return dlrxm;
    }

    public void setDlrxm(String dlrxm) {
        this.dlrxm = dlrxm;
    }

    public String getDlrzjlb() {
        return dlrzjlb;
    }

    public void setDlrzjlb(String dlrzjlb) {
        this.dlrzjlb = dlrzjlb;
    }

    public String getDlrzjhm() {
        return dlrzjhm;
    }

    public void setDlrzjhm(String dlrzjhm) {
        this.dlrzjhm = dlrzjhm;
    }

    public String getDlrdz() {
        return dlrdz;
    }

    public void setDlrdz(String dlrdz) {
        this.dlrdz = dlrdz;
    }

    public String getDlrlxdh() {
        return dlrlxdh;
    }

    public void setDlrlxdh(String dlrlxdh) {
        this.dlrlxdh = dlrlxdh;
    }

    public String getDlryb() {
        return dlryb;
    }

    public void setDlryb(String dlryb) {
        this.dlryb = dlryb;
    }

    public String getDlrgj() {
        return dlrgj;
    }

    public void setDlrgj(String dlrgj) {
        this.dlrgj = dlrgj;
    }

    public Date getDlrcsrq() {
        return dlrcsrq;
    }

    public void setDlrcsrq(Date dlrcsrq) {
        this.dlrcsrq = dlrcsrq;
    }

    public String getDlrxb() {
        return dlrxb;
    }

    public void setDlrxb(String dlrxb) {
        this.dlrxb = dlrxb;
    }

    public String getDbrxm() {
        return dbrxm;
    }

    public void setDbrxm(String dbrxm) {
        this.dbrxm = dbrxm;
    }

    public String getDbrzjlb() {
        return dbrzjlb;
    }

    public void setDbrzjlb(String dbrzjlb) {
        this.dbrzjlb = dbrzjlb;
    }

    public String getDbrzjhm() {
        return dbrzjhm;
    }

    public void setDbrzjhm(String dbrzjhm) {
        this.dbrzjhm = dbrzjhm;
    }

    public String getDbrdz() {
        return dbrdz;
    }

    public void setDbrdz(String dbrdz) {
        this.dbrdz = dbrdz;
    }

    public String getDbrlxdh() {
        return dbrlxdh;
    }

    public void setDbrlxdh(String dbrlxdh) {
        this.dbrlxdh = dbrlxdh;
    }

    public String getDbryb() {
        return dbryb;
    }

    public void setDbryb(String dbryb) {
        this.dbryb = dbryb;
    }

    public String getDbrgj() {
        return dbrgj;
    }

    public void setDbrgj(String dbrgj) {
        this.dbrgj = dbrgj;
    }

    public Date getDbrcsrq() {
        return dbrcsrq;
    }

    public void setDbrcsrq(Date dbrcsrq) {
        this.dbrcsrq = dbrcsrq;
    }

    public String getDbrxb() {
        return dbrxb;
    }

    public void setDbrxb(String dbrxb) {
        this.dbrxb = dbrxb;
    }

    public String getYyzzzch() {
        return yyzzzch;
    }

    public void setYyzzzch(String yyzzzch) {
        this.yyzzzch = yyzzzch;
    }

    public String getQyzzzsh() {
        return qyzzzsh;
    }

    public void setQyzzzsh(String qyzzzsh) {
        this.qyzzzsh = qyzzzsh;
    }

    public String getWtxsjjjg() {
        return wtxsjjjg;
    }

    public void setWtxsjjjg(String wtxsjjjg) {
        this.wtxsjjjg = wtxsjjjg;
    }

    public String getJjjgbazmh() {
        return jjjgbazmh;
    }

    public void setJjjgbazmh(String jjjgbazmh) {
        this.jjjgbazmh = jjjgbazmh;
    }

    public String getDbrlx() {
        return dbrlx;
    }

    public void setDbrlx(String dbrlx) {
        this.dbrlx = dbrlx;
    }

    public String getJjjgtxdz() {
        return jjjgtxdz;
    }

    public void setJjjgtxdz(String jjjgtxdz) {
        this.jjjgtxdz = jjjgtxdz;
    }

    public String getJjjgyzbm() {
        return jjjgyzbm;
    }

    public void setJjjgyzbm(String jjjgyzbm) {
        this.jjjgyzbm = jjjgyzbm;
    }

    public String getJjjgyyzzzch() {
        return jjjgyyzzzch;
    }

    public void setJjjgyyzzzch(String jjjgyyzzzch) {
        this.jjjgyyzzzch = jjjgyyzzzch;
    }

    public String getDlrlx() {
        return dlrlx;
    }

    public void setDlrlx(String dlrlx) {
        this.dlrlx = dlrlx;
    }

    public String getDlrgjdqlx() {
        return dlrgjdqlx;
    }

    public void setDlrgjdqlx(String dlrgjdqlx) {
        this.dlrgjdqlx = dlrgjdqlx;
    }

    public String getDlrgjdq() {
        return dlrgjdq;
    }

    public void setDlrgjdq(String dlrgjdq) {
        this.dlrgjdq = dlrgjdq;
    }

    public String getDbrgjdqlx() {
        return dbrgjdqlx;
    }

    public void setDbrgjdqlx(String dbrgjdqlx) {
        this.dbrgjdqlx = dbrgjdqlx;
    }

    public String getDbrgjdq() {
        return dbrgjdq;
    }

    public void setDbrgjdq(String dbrgjdq) {
        this.dbrgjdq = dbrgjdq;
    }

    public Integer getSxh() {
        return sxh;
    }

    public void setSxh(Integer sxh) {
        this.sxh = sxh;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
